@@ -16,6 +16,7 @@ var httpSignature = require('../lib/index');
 ///--- Globals
 
 var hmacKey = null;
+var rawhmacKey = null;
 var options = null;
 var rsaPrivate = null;
 var rsaPublic = null;
@@ -45,6 +46,8 @@ test('setup', function(t) {
   t.ok(ecdsaPublic);
 
   hmacKey = uuid();
+  rawhmacKey = crypto.randomBytes(64);
+
   socket = '/tmp/.' + uuid();
   options = {
     socketPath: socket,
@@ -107,6 +110,49 @@ test('valid hmac', function(t) {
   });
 });
 
+test('invalid raw hmac', function(t) {
+  server.tester = function(req, res) {
+    var parsed = httpSignature.parseRequest(req);
+    t.ok(!httpSignature.verifyHMAC(parsed, rawhmacKey));
+
+    res.writeHead(200);
+    res.write(JSON.stringify(parsed, null, 2));
+    res.end();
+  };
+
+  options.headers.Date = jsprim.rfc1123(new Date());
+  options.headers.Authorization =
+    'Signature keyId="foo",algorithm="hmac-sha1",signature="' +
+     uuid() + '"';
+
+  http.get(options, function(res) {
+    t.equal(res.statusCode, 200);
+    t.end();
+  });
+});
+
+test('valid raw hmac', function(t) {
+  server.tester = function(req, res) {
+    var parsed = httpSignature.parseRequest(req);
+    t.ok(httpSignature.verifyHMAC(parsed, rawhmacKey));
+
+    res.writeHead(200);
+    res.write(JSON.stringify(parsed, null, 2));
+    res.end();
+  };
+
+  options.headers.Date = jsprim.rfc1123(new Date());
+  var hmac = crypto.createHmac('sha1', rawhmacKey);
+  hmac.update('date: ' + options.headers.Date);
+  options.headers.Authorization =
+    'Signature keyId="foo",algorithm="hmac-sha1",signature="' +
+    hmac.digest('base64') + '"';
+
+  http.get(options, function(res) {
+    t.equal(res.statusCode, 200);
+    t.end();
+  });
+});
 
 test('invalid rsa', function(t) {
   server.tester = function(req, res) {
